package com.bonus.canteen.core.menu.service;

import java.util.List;
import com.bonus.canteen.core.menu.domain.MenuEvaluaOrder;
import com.bonus.canteen.core.menu.dto.MenuEvaluaOrderAddDTO;
import com.bonus.canteen.core.menu.vo.MenuEvaluaOrderVo;

/**
 * 订单评价Service接口
 * 
 * @author xsheng
 * @date 2025-04-20
 */
public interface IMenuEvaluaOrderService {
    /**
     * 查询订单评价
     * 
     * @param id 订单评价主键
     * @return 订单评价
     */
    public MenuEvaluaOrderVo selectMenuEvaluaOrderById(Long id);

    /**
     * 查询订单评价列表
     * 
     * @param menuEvaluaOrder 订单评价
     * @return 订单评价集合
     */
    public List<MenuEvaluaOrder> selectMenuEvaluaOrderList(MenuEvaluaOrder menuEvaluaOrder);

    /**
     * 新增订单评价
     * 
     * @param menuEvaluaOrder 订单评价
     * @return 结果
     */
    public int insertMenuEvaluaOrder(MenuEvaluaOrderAddDTO menuEvaluaOrder);

    /**
     * 修改订单评价
     * 
     * @param menuEvaluaOrder 订单评价
     * @return 结果
     */
    public int updateMenuEvaluaOrder(MenuEvaluaOrder menuEvaluaOrder);

    /**
     * 批量删除订单评价
     * 
     * @param ids 需要删除的订单评价主键集合
     * @return 结果
     */
    public int deleteMenuEvaluaOrderByIds(Long[] ids);

    /**
     * 删除订单评价信息
     * 
     * @param id 订单评价主键
     * @return 结果
     */
    public int deleteMenuEvaluaOrderById(Long id);
}
