package com.bonus.canteen.core.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.bonus.canteen.core.menu.dto.MenuEvaluaOrderAddDTO;
import com.bonus.common.log.enums.OperaType;
import com.bonus.canteen.core.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.menu.domain.MenuEvaluaOrder;
import com.bonus.canteen.core.menu.service.IMenuEvaluaOrderService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 订单评价Controller
 * 
 * @author xsheng
 * @date 2025-04-20
 */
@Api(tags = "订单评价接口")
@RestController
@RequestMapping("/menu_evalua_order")
public class MenuEvaluaOrderController extends BaseController {
    @Autowired
    private IMenuEvaluaOrderService menuEvaluaOrderService;

    /**
     * 查询订单评价列表
     */
    @ApiOperation(value = "查询订单评价列表")
    //@RequiresPermissions("menu:order:list")
    @GetMapping("/list")
    public TableDataInfo list(MenuEvaluaOrder menuEvaluaOrder) {
        startPage();
        List<MenuEvaluaOrder> list = menuEvaluaOrderService.selectMenuEvaluaOrderList(menuEvaluaOrder);
        return getDataTable(list);
    }

    /**
     * 导出订单评价列表
     */
    @ApiOperation(value = "导出订单评价列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:order:export")
    @SysLog(title = "订单评价", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出订单评价")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuEvaluaOrder menuEvaluaOrder) {
        List<MenuEvaluaOrder> list = menuEvaluaOrderService.selectMenuEvaluaOrderList(menuEvaluaOrder);
        ExcelUtil<MenuEvaluaOrder> util = new ExcelUtil<MenuEvaluaOrder>(MenuEvaluaOrder.class);
        util.exportExcel(response, list, "订单评价数据");
    }

    /**
     * 获取订单评价详细信息
     */
//    @ApiOperation(value = "获取订单评价详细信息")
//    //@RequiresPermissions("menu:order:query")
//    @GetMapping(value = "/{evaluaId}")
//    public AjaxResult getInfo(@PathVariable("evaluaId") Long evaluaId) {
//        return success(menuEvaluaOrderService.selectMenuEvaluaOrderById(evaluaId));
//    }

    /**
     * 获取订单评价详细信息
     */
    @ApiOperation(value = "获取订单评价详细信息")
    //@RequiresPermissions("menu:order:query")
    @GetMapping(value = "/orderId/{orderId}")
    public AjaxResult getInfoByOrderId(@PathVariable("orderId") Long orderId) {
        return success(menuEvaluaOrderService.selectMenuEvaluaOrderById(orderId));
    }

    /**
     * 新增订单评价
     */
    @ApiOperation(value = "新增订单评价")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:order:add")
    @SysLog(title = "订单评价", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增订单评价")
    @PostMapping
    public AjaxResult add(@RequestBody MenuEvaluaOrderAddDTO menuEvaluaOrder) {
        try {
            return toAjax(menuEvaluaOrderService.insertMenuEvaluaOrder(menuEvaluaOrder));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改订单评价
     */
    @ApiOperation(value = "修改订单评价")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:order:edit")
    @SysLog(title = "订单评价", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改订单评价")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody MenuEvaluaOrder menuEvaluaOrder) {
        try {
            return toAjax(menuEvaluaOrderService.updateMenuEvaluaOrder(menuEvaluaOrder));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除订单评价
     */
    @ApiOperation(value = "删除订单评价")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:order:remove")
    @SysLog(title = "订单评价", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除订单评价")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(menuEvaluaOrderService.deleteMenuEvaluaOrderByIds(ids));
    }
}
